summaryrefslogtreecommitdiff
path: root/src/include/c.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/include/c.h')
-rw-r--r--src/include/c.h9
1 files changed, 7 insertions, 2 deletions
diff --git a/src/include/c.h b/src/include/c.h
index 4d295510dc..cfce57c070 100644
--- a/src/include/c.h
+++ b/src/include/c.h
@@ -12,7 +12,7 @@
* Portions Copyright (c) 1996-2004, PostgreSQL Global Development Group
* Portions Copyright (c) 1994, Regents of the University of California
*
- * $PostgreSQL: pgsql/src/include/c.h,v 1.171 2004/09/10 15:51:47 momjian Exp $
+ * $PostgreSQL: pgsql/src/include/c.h,v 1.172 2004/09/16 16:58:38 tgl Exp $
*
*-------------------------------------------------------------------------
*/
@@ -351,7 +351,7 @@ typedef float float4;
typedef double float8;
/*
* Oid, RegProcedure, TransactionId, CommandId, AclId
*/
/* typedef Oid is in postgres_ext.h */
@@ -365,6 +365,11 @@ typedef regproc RegProcedure;
typedef uint32 TransactionId;
+typedef uint32 SubTransactionId;
+
+#define InvalidSubTransactionId ((SubTransactionId) 0)
+#define TopSubTransactionId ((SubTransactionId) 1)
+
typedef uint32 CommandId;
#define FirstCommandId ((CommandId) 0)
@@ -351,7 +351,7 @@ typedef float float4;
typedef double float8;
/*
- * Oid, RegProcedure, TransactionId, CommandId, AclId
+ * Oid, RegProcedure, TransactionId, SubTransactionId, CommandId, AclId
*/
/* typedef Oid is in postgres_ext.h */